@@ -4,8 +4,9 @@
 
 from __future__ import print_function, unicode_literals
 import os
-import os.path
+# import os.path
 import sys
+import stat
 import subprocess
 from string import Template
 from subprocess import Popen, PIPE
@@ -14,11 +15,10 @@ import argparse
 import glob
 from os0 import os0
 import magic
+from python_plus import _c
 
 
-__version__ = "1.0.5"
-# Module to test version (if supplied version test is executed)
-# REQ_TEST_VERSION = "0.1.4"
+__version__ = "1.0.6.1"
 
 # return code
 TEST_FAILED = 1
@@ -1488,6 +1488,27 @@ class Z0testOdoo(object):
                 self.testdir = self.this_dir
             self.rundir = self.this_dir
 
+    def simulate_install_pypi(self, cmd):
+        """Simulate pip post installation for """
+        PYCODE = r"""#!%(exec)s
+# -*- coding: utf-8 -*-
+import re
+import sys
+from %(pypi)s.scripts.%(cmd)s import main
+if __name__ == '__main__':
+    sys.argv[0] = re.sub(r'(-script\.pyw|\.exe)?$', '', sys.argv[0])
+    sys.exit(main())"""
+        params = {
+            'exec': sys.executable,
+            'cmd': os.path.splitext(cmd)[0],
+            'pypi': os.path.basename(self.Z.rundir),
+        }
+        with open(os.path.join(self.Z.rundir, cmd), 'w') as fd:
+            fd.write(_c(PYCODE % params))
+            mode = os.fstat(fd.fileno()).st_mode
+            mode |= stat.S_IXUSR | stat.S_IXGRP | stat.S_IXOTH
+            os.fchmod(fd.fileno(), stat.S_IMODE(mode))
+
     def get_outer_dir(self):
         """Get dir out of current virtual environment
         In local tests it serves to find local Odoo repositories to avoid
